==> jc-1.4.0.tar.gz: java/security/Signer.h <==
// public abstract class java.security.Signer

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class cab74eaae059bd6e java_security_Identity
// @dep_class a26a24e3a732b375 java_security_Signer

// header file dependencies
// @dep_header java_security_Identity

#include "java/security/Identity.h"

#ifndef _JC_java_security_Signer_H_
#define _JC_java_security_Signer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_IdentityScope$object;
struct _jc_java_security_KeyPair$object;
struct _jc_java_security_PrivateKey$object;

// Typedefs
typedef struct _jc_java_security_Signer$sub_refs	_jc_java_security_Signer$sub_refs;
typedef struct _jc_java_security_Signer$sub_nonrefs	_jc_java_security_Signer$sub_nonrefs;
typedef struct _jc_java_security_Signer$refs	_jc_java_security_Signer$refs;
typedef struct _jc_java_security_Signer$nonrefs	_jc_java_security_Signer$nonrefs;
typedef struct _jc_java_security_Signer$object	_jc_java_security_Signer$object;

typedef struct _jc_java_security_Signer$fields_struct	_jc_java_security_Signer$fields_struct;
typedef const struct _jc_java_security_Signer$vmethods	_jc_java_security_Signer$vmethods;
typedef const struct _jc_java_security_Signer$vtable	_jc_java_security_Signer$vtable;
typedef const struct _jc_java_security_Signer$vtype	_jc_java_security_Signer$vtype;

// Class fields structure
struct _jc_java_security_Signer$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_Signer$fields_struct _jc_java_security_Signer$class_fields;

// Constructors
extern void _jc_java_security_Signer$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_Signer$object *);
extern void _jc_java_security_Signer$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_security_Signer$object *, struct _jc_java_lang_String$object *);
extern void _jc_java_security_Signer$method$_init$a03c03f5d4aa0f92(_jc_env *, struct _jc_java_security_Signer$object *, struct _jc_java_lang_String$object *, struct _jc_java_security_IdentityScope$object *);

// Virtual methods
extern struct _jc_object *_jc_java_security_Signer$method$getPrivateKey$e03d9b3f371a9d56(_jc_env *, struct _jc_java_security_Signer$object *);
extern void _jc_java_security_Signer$method$setKeyPair$6fd862861e59c279(_jc_env *, struct _jc_java_security_Signer$object *, struct _jc_java_security_KeyPair$object *);
extern void _jc_java_security_Signer$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_security_Signer$object *);
extern struct _jc_java_lang_String$object *_jc_java_security_Signer$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_security_Signer$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_Signer$method_info$getPrivateKey$e03d9b3f371a9d56;
extern _jc_method _jc_java_security_Signer$method_info$setKeyPair$6fd862861e59c279;
extern _jc_method _jc_java_security_Signer$method_info$this$adc93fb6bf4cbffa;
extern _jc_method _jc_java_security_Signer$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_security_Signer$vmethods {
	struct _jc_object	*(*getPrivateKey$e03d9b3f371a9d56)(_jc_env *, struct _jc_java_security_Signer$object *);
	void	(*setKeyPair$6fd862861e59c279)(_jc_env *, struct _jc_java_security_Signer$object *, struct _jc_java_security_KeyPair$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_security_Signer$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_security_Signer$object *);
};

// Vtable
struct _jc_java_security_Signer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_Identity$vmethods	java_security_Identity;
	_jc_java_security_Signer$vmethods	java_security_Signer;
};

// Vtype
struct _jc_java_security_Signer$vtype {
	_jc_type			type;
	_jc_java_security_Signer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_Signer$sub_refs {
	struct _jc_object	*privateKey;
};

// Reference instance fields (object)
struct _jc_java_security_Signer$refs {
    _jc_java_security_Signer$sub_refs	java_security_Signer;
    _jc_java_security_Identity$sub_refs	java_security_Identity;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_Signer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_Signer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_Identity$sub_nonrefs	java_security_Identity;
    _jc_java_security_Signer$sub_nonrefs	java_security_Signer;
};

// Object instance structure
struct _jc_java_security_Signer$object {
	_jc_java_security_Signer$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_Signer$vtype	*vtype;
	_jc_java_security_Signer$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_Signer$vtype _jc_java_security_Signer$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_Signer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_Signer$class_object;

#endif	/* _JC_java_security_Signer_H_ */

==> jc-1.4.6.tar.gz: java/security/Signer.h <==
// public abstract class java.security.Signer

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class cab74eaae059bd6e java_security_Identity
// @dep_class a26a24e3a732b375 java_security_Signer

// header file dependencies
// @dep_header java_security_Identity

#include "java/security/Identity.h"

#ifndef _JC_java_security_Signer_H_
#define _JC_java_security_Signer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_IdentityScope$object;
struct _jc_java_security_KeyPair$object;
struct _jc_java_security_PrivateKey$object;

// Typedefs
typedef struct _jc_java_security_Signer$sub_refs	_jc_java_security_Signer$sub_refs;
typedef struct _jc_java_security_Signer$sub_nonrefs	_jc_java_security_Signer$sub_nonrefs;
typedef struct _jc_java_security_Signer$refs	_jc_java_security_Signer$refs;
typedef struct _jc_java_security_Signer$nonrefs	_jc_java_security_Signer$nonrefs;
typedef struct _jc_java_security_Signer$object	_jc_java_security_Signer$object;

typedef struct _jc_java_security_Signer$fields_struct	_jc_java_security_Signer$fields_struct;
typedef const struct _jc_java_security_Signer$vmethods	_jc_java_security_Signer$vmethods;
typedef const struct _jc_java_security_Signer$vtable	_jc_java_security_Signer$vtable;
typedef const struct _jc_java_security_Signer$vtype	_jc_java_security_Signer$vtype;

// Class fields structure
struct _jc_java_security_Signer$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_Signer$fields_struct _jc_java_security_Signer$class_fields;

// Constructors
extern void _jc_java_security_Signer$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_Signer$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_Signer$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_security_Signer$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_Signer$method$_init$a03c03f5d4aa0f92(_jc_env *, struct _jc_java_security_Signer$object *, struct _jc_java_lang_String$object *, struct _jc_java_security_IdentityScope$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_java_security_Signer$method$getPrivateKey$e03d9b3f371a9d56(_jc_env *, struct _jc_java_security_Signer$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_Signer$method$setKeyPair$6fd862861e59c279(_jc_env *, struct _jc_java_security_Signer$object *, struct _jc_java_security_KeyPair$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_Signer$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_security_Signer$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_security_Signer$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_security_Signer$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_Signer$method_info$getPrivateKey$e03d9b3f371a9d56;
extern _jc_method _jc_java_security_Signer$method_info$setKeyPair$6fd862861e59c279;
extern _jc_method _jc_java_security_Signer$method_info$this$adc93fb6bf4cbffa;
extern _jc_method _jc_java_security_Signer$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_security_Signer$vmethods {
	struct _jc_object	*(*getPrivateKey$e03d9b3f371a9d56)(_jc_env *, struct _jc_java_security_Signer$object *) _JC_JCNI_ATTR;
	void	(*setKeyPair$6fd862861e59c279)(_jc_env *, struct _jc_java_security_Signer$object *, struct _jc_java_security_KeyPair$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_security_Signer$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_security_Signer$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_Signer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_Identity$vmethods	java_security_Identity;
	_jc_java_security_Signer$vmethods	java_security_Signer;
};

// Vtype
struct _jc_java_security_Signer$vtype {
	_jc_type			type;
	_jc_java_security_Signer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_Signer$sub_refs {
	struct _jc_object	*privateKey;
};

// Reference instance fields (object)
struct _jc_java_security_Signer$refs {
    _jc_java_security_Signer$sub_refs	java_security_Signer;
    _jc_java_security_Identity$sub_refs	java_security_Identity;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_Signer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_Signer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_Identity$sub_nonrefs	java_security_Identity;
    _jc_java_security_Signer$sub_nonrefs	java_security_Signer;
};

// Object instance structure
struct _jc_java_security_Signer$object {
	_jc_java_security_Signer$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_Signer$vtype	*vtype;
	_jc_java_security_Signer$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_Signer$vtype _jc_java_security_Signer$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_Signer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_Signer$class_object;

#endif	/* _JC_java_security_Signer_H_ */
